-------------------------------------------------------------------------------
-- ElvUI Currency Cap Datatext By Lockslap
-- <Borderline Amazing> US, Bleeding Hollow
-------------------------------------------------------------------------------
local E, _, V, P, G, _ = unpack(ElvUI)
local DT = E:GetModule("DataTexts")
local L = LibStub("AceLocale-3.0"):GetLocale("ElvUI_CurrencyCapDT", false)

-- elvui 5.32 change of loadable on demand config
if not IsAddOnLoaded("ElvUI_Config") then LoadAddOn("ElvUI_Config") end

local join = string.join

-- currencies to track.  order is: conquest, honor, justice, and valor
local currencies = {390, 392, 395, 396}
local lastPanel
local displayString = ""

local function OnEvent(self, event, ...)
	local name, amount, _, earned, weekly, total, _ = GetCurrencyInfo(E.db.capdt.currency)
	local currency, first, second = E.db.capdt.currency, 0, 0

	-- valor points
	if currency == 396 then
		first = E.db.capdt.valor == "weekly" and earned or amount
		second = E.db.capdt.valor == "weekly" and 1000 or 3000
	elseif currency == 390 then
		first = E.db.capdt.conquest == "weekly" and earned or amount
		second = weekly
	else
		first = amount
		second = 4000
	end
	
	self.text:SetFormattedText(displayString, name, first, second)
end

local function OnEnter(self)
	local icon = "|TInterface\\Icons\\%s:12:12:1:0|t |cffffffff%s|r"
	DT:SetupTooltip(self)
	
	-- first conquest points
	local name, amount, texture, earned, weekly, total, discovered = GetCurrencyInfo(390)
	if discovered then
		DT.tooltip:AddDoubleLine(icon:format(texture, name), ("|cffffff00%d/%d|r |cff00aa00(%s: %d)|r"):format(earned, weekly, L["Currently"], amount))
	end
	
	-- now honor
	local name, amount, texture, earned, weekly, total, discovered = GetCurrencyInfo(392)
	if discovered then
		DT.tooltip:AddDoubleLine(icon:format(texture, name), ("|cffffff00%d/4000"):format(amount))
	end
	
	-- now valor
	local name, amount, texture, earned, weekly, total, discovered = GetCurrencyInfo(396)
	if discovered then
		DT.tooltip:AddDoubleLine(icon:format(texture, name), ("|cffffff00%d/%d|r |cff00aa00(%d/%d)|r"):format(earned, 1000, amount, 3000))
	end
	
	-- finally justice
	local name, amount, texture, earned, weekly, total, discovered = GetCurrencyInfo(395)
	if discovered then
		DT.tooltip:AddDoubleLine(icon:format(texture, name), ("|cffffff00%d/4000"):format(amount))
	end
	
	DT.tooltip:Show()
end

local function OnClick(self, button)
	ToggleCharacter("TokenFrame")
end

local function ValueColorUpdate(hex, r, g, b)
	displayString = join("", "|cffffffff%s:|r", " ", hex, "%d|r", "|cffffffff/|r", hex, "%d|r")
	if lastPanel ~= nil then OnEvent(lastPanel) end
end
E["valueColorUpdateFuncs"][ValueColorUpdate] = true

P["capdt"] = {
	["currency"] = 390,
	["conquest"] = "weekly",
	["valor"] = "weekly",
}

E.Options.args.datatexts.args.capdt = {
	type = "group",
	order = 24,
	name = L["Currency Cap Datatext"],
	guiInline = true,
	get = function(info) return E.db.capdt[info[#info]] end,
	set = function(info, value) E.db.capdt[info[#info]] = value; DT:LoadDataTexts(); end,
	args = {
		currency = {
			type = "select",
			order = 1,
			name = L["Currency Cap To Track"],
			desc = L["Select which currency cap to track."],
			values = {
				[390] = L["Conquest Points"],
				[392] = L["Honor Points"],
				[395] = L["Justice Points"],
				[396] = L["Valor Points"],
			},
		},
		conquest = {
			type = "select",
			order = 2,
			name = L["Conquest Cap Display"],
			desc = L["Select which amount of conquest points you want to display, either how many you currently have, or how many you've earned this week."],
			values = {
				["weekly"] = L["Earned This Week"],
				["current"] = L["Current Amount"],
			},
			disabled = function() return E.db.capdt.currency ~= 390 end,
		},
		valor = {
			type = "select",
			order = 3,
			name = L["Valor Cap Display"],
			desc = L["Select which cap to monitor for Valor Points, weekly or total."],
			values = {
				["weekly"] = L["Weekly Cap"],
				["total"] = L["Total Cap"],
			},
			disabled = function() return E.db.capdt.currency ~= 396 end,
		},
	},
}

DT:RegisterDatatext(L["Currency Cap"], {"PLAYER_ENTERING_WORLD", "CHAT_MSG_CURRENCY"}, OnEvent, nil, Click, OnEnter)